import { Plugin } from 'esbuild';
import { LogLevel } from './logger.cjs';

interface ScriptableBannerOptions {
    /**
     * Log level for the plugin
     * 'auto' will use esbuild's logLevel
     * Default: 'auto'
     */
    logLevel?: LogLevel | 'auto';
    /** Custom manifest file extensions */
    manifestExtensions?: string[];
    /** Show warning when manifest file is missing */
    warnOnMissingManifest?: boolean;
    /** Show warning when manifest file is invalid */
    warnOnInvalidManifest?: boolean;
    /** Show warning when no matching entry point is found */
    warnOnMissingEntry?: boolean;
    /** Allow extra keys in the manifest */
    allowExtraManifestKeys?: boolean;
    /**glob matching pattern, supports ! prefix to exclude files */
    patterns?: string | string[];
    /** Custom manifest file path mapping function */
    getManifestPath?: (entryPath: string) => string;
}
declare function scriptableBanner(options?: ScriptableBannerOptions): Plugin;

export { type ScriptableBannerOptions, scriptableBanner };
